@@ -30,7 +30,6 @@
 #include <libgnomeui/gnome-help.h>
 #include <gtk/gtkaboutdialog.h>
 #include <gtk/gtkmessagedialog.h>
-#include <gtk/gtktooltips.h>
 #include <libwnck/screen.h>
 #include <libwnck/util.h>
 
@@ -40,24 +39,6 @@
 #include "window-list.h"
 #include "showdesktop.h"
 
-void
-wncklet_set_tooltip (GtkWidget  *widget,
-		     const char *tip)
-{
-        GtkTooltips *tooltips;
-
-        tooltips = g_object_get_data (G_OBJECT (widget), "tooltips");
-        if (!tooltips) {
-                tooltips = gtk_tooltips_new ();
-                g_object_ref (tooltips);
-                gtk_object_sink (GTK_OBJECT (tooltips));
-                g_object_set_data_full (G_OBJECT (widget), "tooltips", tooltips,
-                                        (GDestroyNotify) g_object_unref);
-        }
-
-        gtk_tooltips_set_tip (tooltips, widget, tip, NULL);
-}
-
 void
 wncklet_display_about (GtkWidget   *applet,
 		       GtkWidget  **dialog,
@@ -80,7 +61,7 @@ wncklet_display_about (GtkWidget   *applet,
 
 	*dialog = gtk_about_dialog_new ();
 	g_object_set (*dialog,
-		      "name",  name,
+		      "program-name",  name,
 		      "version", VERSION,
 		      "copyright", copyright,
 		      "comments", comments,
@@ -207,12 +188,12 @@ PANEL_APPLET_BONOBO_SHLIB_FACTORY ("OAFIID:GNOME_Wncklet_Factory",
 				   PANEL_TYPE_APPLET,
 				   "WindowNavigationApplets",
 				   wncklet_factory,
-				   NULL);
+				   NULL)
 #else
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_Wncklet_Factory",
                              PANEL_TYPE_APPLET,
                              "WindowNavigationApplets",
                              "0",
                              wncklet_factory,
-                             NULL);
+                             NULL)
 #endif
